# BiGAr Boolean Subtraction and Voxelization Scripts, part 2
# This script extrude two surfaces into Blender and prepares the result for a Boolean subtraction.
# Copyright (C) 2024 Dr. Marco Cavalazzi, see acknowledgements at <https://site.unibo.it/bim-gis-integration-for-archaeology/en>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.

import bpy

def extrude_mesh_along_y(obj, distance):
    # Set the object to edit mode
    bpy.context.view_layer.objects.active = obj
    bpy.ops.object.mode_set(mode='EDIT')

    # Select all faces
    bpy.ops.mesh.select_all(action='SELECT')

    # Extrude faces along the Y axis
    bpy.ops.mesh.extrude_region_move(
        MESH_OT_extrude_region={"use_normal_flip": False, "use_dissolve_ortho_edges": False},
        TRANSFORM_OT_translate={"value": (0, distance, 0)}  # Extruding along Y axis
    )

    # Switch back to object mode
    bpy.ops.object.mode_set(mode='OBJECT')

# Mesh object names
mesh1_name = 'Your Stratigraphic Unit 1'
mesh2_name = 'Your Stratigraphic Unit 2'

# Get the mesh objects
obj1 = bpy.data.objects[mesh1_name]
obj2 = bpy.data.objects[mesh2_name]

# Extrude the meshes along the Y axis by 10 units
extrude_mesh_along_y(obj1, 5)
extrude_mesh_along_y(obj2, 5)
