# BiGAr Boolean Subtraction and Voxelization Scripts, part 3
# This scrip subtract two extruded surfaces into Blender and prepares the result for voxelization.
# Copyright (C) 2024 Dr. Marco Cavalazzi, see acknowledgements at <https://site.unibo.it/bim-gis-integration-for-archaeology/en>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>

import bpy

# Names of the two meshes
mesh_1_name = "Your Stratigraphic Unit 1"  # Name of the target mesh
mesh_2_name = "Your Stratigraphic Unit 2"  # Name of the mesh to subtract

# Ensure the meshes exist in the scene
if mesh_1_name in bpy.data.objects and mesh_2_name in bpy.data.objects:
    # Get the objects
    mesh_1 = bpy.data.objects[mesh_1_name]
    mesh_2 = bpy.data.objects[mesh_2_name]
    
    # Create a boolean modifier
    boolean_modifier = mesh_1.modifiers.new(name="Boolean Modifier", type='BOOLEAN')
    
    # Set the operation to difference (subtraction)
    boolean_modifier.operation = 'DIFFERENCE'
    
    # Set the object to subtract
    boolean_modifier.object = mesh_2
    
    # Apply the modifier
    bpy.context.view_layer.objects.active = mesh_1
    bpy.ops.object.modifier_apply(modifier=boolean_modifier.name)
    
    # Optionally, delete the subtracted mesh
    bpy.data.objects.remove(mesh_2, do_unlink=True)
    
    print(f"Boolean subtraction applied successfully between {mesh_1_name} and {mesh_2_name}.")
else:
    print("One or both meshes not found in the scene.")
